@@ -56,6 +56,7 @@ class pub(object):
          'poll',
          'log_level',
          'isy_info',
+         'config_done',
          ]
 
     topics = {}
@@ -75,7 +76,7 @@ class pub(object):
         if pub.topic_list[topic] in pub.topics:
             for item in pub.topics[pub.topic_list[topic]]:
                 if item[1] == address:
-                    item[0](*argv)
+                    Thread(target=item[0], args=[*argv]).start()
         
 
 
@@ -97,6 +98,7 @@ class Interface(object):
     POLL              = 11
     LOGLEVEL          = 12
     ISY               = 13
+    CONFIGDONE        = 14
 
     """
     Polyglot Interface Class
@@ -113,7 +115,6 @@ class Interface(object):
             warnings.warn('Only one Interface is allowed.')
             return
         try:
-            LOGGER.error('PG3INIT = {}'.format(os.environ.get('PG3INIT')))
             self.pg3init = json.loads(
                 base64.b64decode(os.environ.get('PG3INIT')))
         except:
@@ -233,7 +234,8 @@ class Interface(object):
             inputCmds = ['query', 'command', 'addnode', 'stop',
                          'status', 'shortPoll', 'longPoll', 'delete',
                          'config', 'customdata', 'customparams', 'notices',
-                         'getIsyInfo', 'getAll', 'setLogLevel']
+                         'getIsyInfo', 'getAll', 'setLogLevel',
+                         'customtypeddata']
 
             parsed_msg = json.loads(msg.payload.decode('utf-8'))
             #LOGGER.debug('MQTT Received Message: {}: {}'.format(msg.topic, parsed_msg))
@@ -286,7 +288,7 @@ class Interface(object):
                     LOGGER.info('customparamsdoc response')
                 else:
                     LOGGER.error(
-                        'Invalid command received in message from PG3: \'{}\''.format(key))
+                        'Invalid command received in message from PG3: \'{}\' {}'.format(key, parsed_msg[key]))
         except (ValueError) as err:
             LOGGER.error('MQTT Received Payload Error: {}'.format(
                 err), exc_info=True)
@@ -528,6 +530,8 @@ class Interface(object):
                 if isinstance(input[key], list):
                     for item in input[key]:
                         self._handleInput(key, item)
+                    if key == 'getAll':
+                        pub.publish(self.CONFIGDONE, None, None)
                 else:
                     self._handleInput(key, input[key])
             self.inQueue.task_done()
@@ -543,6 +547,14 @@ class Interface(object):
             except ValueError as e:
                 value = item.get('value')
 
+            pub.publish(self.CUSTOMDATA, None, value)
+        elif key == 'customtypeddata':
+            #LOGGER.debug('customTypedData: {}'.format(item))
+            try:
+                value = json.loads(item)
+            except ValueError as e:
+                value = item.get('value')
+
             pub.publish(self.CUSTOMDATA, None, value)
         elif key == 'customparams':
             #LOGGER.debug('customParams: {}'.format(item))
@@ -762,9 +774,9 @@ class Interface(object):
         """
         LOGGER.info('Removing node {}'.format(address))
         message = {
-            'removenode': {
+            'removenode': [{
                 'address': address
-            }
+            }]
         }
         self.send(message, 'command')
 
